==> cscec5b-fbxt-api-3.0.1-20230526.005839-115-sources.jar: com/ejianc/business/fbxt/odd/vo/sysupl/OddInfoVO.java <==
package com.ejianc.business.fbxt.odd.vo.sysupl;

import java.math.BigDecimal;
import java.util.List;

public class OddInfoVO {
    private static final long serialVersionUID = 1L;
    private Long pkOddinfo;
    private Long pkOdd;
    private Long pkApplyInfo;
    private BigDecimal applyAmount;
    private String infoName;
    private BigDecimal infoAmount;
    private BigDecimal unitPrice;
    private String infoUnit;
    private BigDecimal sumPrice;//金额
    private BigDecimal infoAmountCheck;
    private BigDecimal unitPriceCheck;
    private BigDecimal sumPriceCheck;//审核金额
    private String beginTime;
    private String endTime;
    private String befUrl;
    private String aftUrl;
    private List<FileRelation> befFileList;
    private List<FileRelation> aftFileList;
    private String infoCode;


    public String getInfoCode() {
        return infoCode;
    }

    public void setInfoCode(String infoCode) {
        this.infoCode = infoCode;
    }

    public List<FileRelation> getBefFileList() {
        return befFileList;
    }

    public void setBefFileList(List<FileRelation> befFileList) {
        this.befFileList = befFileList;
    }

    public List<FileRelation> getAftFileList() {
        return aftFileList;
    }

    public void setAftFileList(List<FileRelation> aftFileList) {
        this.aftFileList = aftFileList;
    }

    public Long getPkOddinfo() {
        return pkOddinfo;
    }

    public void setPkOddinfo(Long pkOddinfo) {
        this.pkOddinfo = pkOddinfo;
    }

    public Long getPkOdd() {
        return pkOdd;
    }

    public void setPkOdd(Long pkOdd) {
        this.pkOdd = pkOdd;
    }

    public Long getPkApplyInfo() {
        return pkApplyInfo;
    }

    public void setPkApplyInfo(Long pkApplyInfo) {
        this.pkApplyInfo = pkApplyInfo;
    }

    public BigDecimal getApplyAmount() {
        return applyAmount;
    }

    public void setApplyAmount(BigDecimal applyAmount) {
        this.applyAmount = applyAmount;
    }

    public String getInfoName() {
        return infoName;
    }

    public void setInfoName(String infoName) {
        this.infoName = infoName;
    }

    public BigDecimal getInfoAmount() {
        return infoAmount;
    }

    public void setInfoAmount(BigDecimal infoAmount) {
        this.infoAmount = infoAmount;
    }

    public BigDecimal getUnitPrice() {
        return unitPrice;
    }

    public void setUnitPrice(BigDecimal unitPrice) {
        this.unitPrice = unitPrice;
    }

    public String getInfoUnit() {
        return infoUnit;
    }

    public void setInfoUnit(String infoUnit) {
        this.infoUnit = infoUnit;
    }

    public BigDecimal getSumPrice() {
        return sumPrice;
    }

    public void setSumPrice(BigDecimal sumPrice) {
        this.sumPrice = sumPrice;
    }

    public BigDecimal getInfoAmountCheck() {
        return infoAmountCheck;
    }

    public void setInfoAmountCheck(BigDecimal infoAmountCheck) {
        this.infoAmountCheck = infoAmountCheck;
    }

    public BigDecimal getUnitPriceCheck() {
        return unitPriceCheck;
    }

    public void setUnitPriceCheck(BigDecimal unitPriceCheck) {
        this.unitPriceCheck = unitPriceCheck;
    }

    public BigDecimal getSumPriceCheck() {
        return sumPriceCheck;
    }

    public void setSumPriceCheck(BigDecimal sumPriceCheck) {
        this.sumPriceCheck = sumPriceCheck;
    }

    public String getBeginTime() {
        return beginTime;
    }

    public void setBeginTime(String beginTime) {
        this.beginTime = beginTime;
    }

    public String getEndTime() {
        return endTime;
    }

    public void setEndTime(String endTime) {
        this.endTime = endTime;
    }

    public String getBefUrl() {
        return befUrl;
    }

    public void setBefUrl(String befUrl) {
        this.befUrl = befUrl;
    }

    public String getAftUrl() {
        return aftUrl;
    }

    public void setAftUrl(String aftUrl) {
        this.aftUrl = aftUrl;
    }
}

==> cscec5b-fbxt-api-3.0.1-20240221.074023-183-sources.jar: com/ejianc/business/fbxt/odd/vo/sysupl/OddInfoVO.java <==
package com.ejianc.business.fbxt.odd.vo.sysupl;

import java.math.BigDecimal;
import java.util.List;

public class OddInfoVO {
    private static final long serialVersionUID = 1L;
    private Long pkOddinfo;
    private Long pkOdd;
    private Long pkApplyInfo;
    private BigDecimal applyAmount;
    private String infoName;
    private BigDecimal infoAmount;
    private BigDecimal unitPrice;
    private String infoUnit;
    private BigDecimal sumPrice;//金额
    private BigDecimal infoAmountCheck;
    private BigDecimal unitPriceCheck;
    private BigDecimal sumPriceCheck;//审核金额
    private String beginTime;
    private String endTime;
    private String befUrl;
    private String aftUrl;
    private String pkMeasdoc; // 单位主键
    private String pkAmountlist; // 分录主键
    private String htywnr; // 分录名称
    private String sourceId; // 来源主键
    private List<FileRelation> befFileList;
    private List<FileRelation> aftFileList;
    private String infoCode;


    public String getInfoCode() {
        return infoCode;
    }

    public void setInfoCode(String infoCode) {
        this.infoCode = infoCode;
    }

    public List<FileRelation> getBefFileList() {
        return befFileList;
    }

    public void setBefFileList(List<FileRelation> befFileList) {
        this.befFileList = befFileList;
    }

    public List<FileRelation> getAftFileList() {
        return aftFileList;
    }

    public void setAftFileList(List<FileRelation> aftFileList) {
        this.aftFileList = aftFileList;
    }

    public Long getPkOddinfo() {
        return pkOddinfo;
    }

    public void setPkOddinfo(Long pkOddinfo) {
        this.pkOddinfo = pkOddinfo;
    }

    public Long getPkOdd() {
        return pkOdd;
    }

    public void setPkOdd(Long pkOdd) {
        this.pkOdd = pkOdd;
    }

    public Long getPkApplyInfo() {
        return pkApplyInfo;
    }

    public void setPkApplyInfo(Long pkApplyInfo) {
        this.pkApplyInfo = pkApplyInfo;
    }

    public BigDecimal getApplyAmount() {
        return applyAmount;
    }

    public void setApplyAmount(BigDecimal applyAmount) {
        this.applyAmount = applyAmount;
    }

    public String getInfoName() {
        return infoName;
    }

    public void setInfoName(String infoName) {
        this.infoName = infoName;
    }

    public BigDecimal getInfoAmount() {
        return infoAmount;
    }

    public void setInfoAmount(BigDecimal infoAmount) {
        this.infoAmount = infoAmount;
    }

    public BigDecimal getUnitPrice() {
        return unitPrice;
    }

    public void setUnitPrice(BigDecimal unitPrice) {
        this.unitPrice = unitPrice;
    }

    public String getInfoUnit() {
        return infoUnit;
    }

    public void setInfoUnit(String infoUnit) {
        this.infoUnit = infoUnit;
    }

    public BigDecimal getSumPrice() {
        return sumPrice;
    }

    public void setSumPrice(BigDecimal sumPrice) {
        this.sumPrice = sumPrice;
    }

    public BigDecimal getInfoAmountCheck() {
        return infoAmountCheck;
    }

    public void setInfoAmountCheck(BigDecimal infoAmountCheck) {
        this.infoAmountCheck = infoAmountCheck;
    }

    public BigDecimal getUnitPriceCheck() {
        return unitPriceCheck;
    }

    public void setUnitPriceCheck(BigDecimal unitPriceCheck) {
        this.unitPriceCheck = unitPriceCheck;
    }

    public BigDecimal getSumPriceCheck() {
        return sumPriceCheck;
    }

    public void setSumPriceCheck(BigDecimal sumPriceCheck) {
        this.sumPriceCheck = sumPriceCheck;
    }

    public String getBeginTime() {
        return beginTime;
    }

    public void setBeginTime(String beginTime) {
        this.beginTime = beginTime;
    }

    public String getEndTime() {
        return endTime;
    }

    public void setEndTime(String endTime) {
        this.endTime = endTime;
    }

    public String getBefUrl() {
        return befUrl;
    }

    public void setBefUrl(String befUrl) {
        this.befUrl = befUrl;
    }

    public String getAftUrl() {
        return aftUrl;
    }

    public void setAftUrl(String aftUrl) {
        this.aftUrl = aftUrl;
    }

    public String getPkMeasdoc() {
        return pkMeasdoc;
    }

    public void setPkMeasdoc(String pkMeasdoc) {
        this.pkMeasdoc = pkMeasdoc;
    }

    public String getPkAmountlist() {
        return pkAmountlist;
    }

    public void setPkAmountlist(String pkAmountlist) {
        this.pkAmountlist = pkAmountlist;
    }

    public String getHtywnr() {
        return htywnr;
    }

    public void setHtywnr(String htywnr) {
        this.htywnr = htywnr;
    }

    public String getSourceId() {
        return sourceId;
    }

    public void setSourceId(String sourceId) {
        this.sourceId = sourceId;
    }
}
